@@ -10,18 +10,28 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(system system_ex log);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub system
 {
     return system_ex(@_);
 }
 
+sub system_log
+{
+    my $start = time;
+    my $r = system_ex(@_);
+    my $end = time;
+    my $timecost = $end - $start;
+    System::Timeout::log('system', $r, $timecost, $$, @_);
+    System::Timeout::log('system_fail', $r, $timecost, $$, @_) unless $r == 0 ;
+    return $r;
+}
+
 sub system_ex
 {
     return 0 unless $_[0];
     my $r = 0;
-    my $start = time;
     unless ($_[0] =~ /^\d+$/)
     {
         $r = CORE::system(@_);
@@ -61,10 +71,6 @@ sub system_ex
             }
         }
     }
-    my $end = time;
-    my $timecost = $end - $start;
-    System::Timeout::log('system', $r, $timecost, $$, @_);
-    System::Timeout::log('system_fail', $r, $timecost, $$, @_) unless $r == 0 ;
     return $r;
 }
 
@@ -98,36 +104,38 @@ __END__
 
 =head1 NAME
 
-System::Timeout - Extend <system()> to Allow Timeout after specified seconds
+System::Timeout - extend system() to allow timeout after specified seconds
 
 
 =head1 SYNOPSIS
 
-  use System::Timeout qw(system system_ex);
-  system("3", "sleep 9");
-  system_ex("3", "sleep 9");
+  use System::Timeout qw(system system_ex system_log);
+  system_ex("sleep 9"); # invoke CORE::system, will not timeout exit
+  system_ex("3", "sleep 9"); # timeout exit after 3 seconds
+
+  system("3", "sleep 9"); # just an alias for system_ex, for peoples who want to overlay the Perl build-in
+
+  system_log("3", "sleep 9"); # log the command in file
+
+
 
   % timeout --timeout=3 "sleep 9"  #Run command "Sleep 9" and timeout after 3 seconds
 
 
 =head1 DESCRIPTION
 
-This module extends <system()> to allow timeout after the specified seconds and log the command in file.
-This can be useful when invoking <system()> in daemon.
+This module extends system() to allow timeout after the specified seconds.
 This also include a cli tool "timeout" which can be easily used to force command exit after specified seconds.
-This module is based on core function <fork()> and <exec()>.
+This module is based on core function fork(), exec(), sleep().
+These can be useful when invoking system() in daemon.
 
 
 =head1 AUTHOR
 
-Written by Chen Gang, yikuyiku.com@gmail.com
+Written by ChenGang, yikuyiku.com@gmail.com
 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011 Chen Gang.
-
-This library is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
-
-
+Copyright (c) 2011 ChenGang.
+This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
